@@ -44,7 +44,7 @@ G_BEGIN_DECLS
 #define GPA_NODE_PARENT(n)       (GPA_NODE (n)->parent)
 
 typedef enum {
-	NODE_FLAG_LOCKED = 1 << 4, /* Used for options when an option can't change from the default */
+	NODE_FLAG_LOCKED = 1 << 4 /* Used for options when an option can't change from the default */
 } GPANodeFlags;
 
 struct _GPANode {
